

.. _sphx_glr_content_user_guide_auto_examples_2cross:

2 | Cross-Set Analysis
========================



.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Maximum Covariance Analysis (MCA) between two data sets.">

.. only:: html

  .. image:: /content/user_guide/auto_examples/2cross/images/thumb/sphx_glr_plot_mca_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_2cross_plot_mca.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Maximum Covariance Analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Rotated Maximum Covariance Analysis (MCA) between two data sets.">

.. only:: html

  .. image:: /content/user_guide/auto_examples/2cross/images/thumb/sphx_glr_plot_rotated_mca_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_2cross_plot_rotated_mca.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Rotated Maximum Covariance Analysis</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /content/user_guide/auto_examples/2cross/plot_mca
   /content/user_guide/auto_examples/2cross/plot_rotated_mca

